@@ -2,32 +2,38 @@
 general<-function(x, y,adj, data,outformat=2){
   xx<-data[,x]
   yy<-data[,y]
-  #确认调整变量不同于x,y
-  adj1<-setdiff(adj, c(x, y))
-  #model和调整model的表达式
+  #Formula of model
   formula_crude<-stats::as.formula(paste0(y, ' ~ ', x))
-  formula_adj<-stats::as.formula(paste0(y, ' ~ ', x , ' + ', paste(adj1, collapse = ' + ')))
-  #general regression
+  if(length(adj)==0){
+    formula_adj<-stats::as.formula(paste0(y, ' ~ ', x))
+  }else{
+    formula_adj<-stats::as.formula(paste0(y, ' ~ ', x , ' + ', paste(adj, collapse = ' + ')))
+    }
+  #General regression
   model_crude<-stats::glm(formula_crude, data = data, family = stats::gaussian())
   model_adj<-stats::glm(formula_adj, data = data, family = stats::gaussian())
-  #计算OR值、p值并输出
+  #Compute OR and p value
   if(is.factor(xx)){
     summary_y<-NULL
-    #计算p-trend
+    #Compute p-trend
     formula_crude_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ')'))
     model_crude_trend<-stats::glm(formula_crude_trend, data = data, family = stats::gaussian())
 
-    formula_adj_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ') +', paste(adj1, collapse = ' + ')))
+    if(length(adj)==0){
+      formula_adj_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ')'))
+    }else{
+      formula_adj_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ') +', paste(adj, collapse = ' + ')))
+      }
     model_adj_trend<-stats::glm(formula_adj_trend, data = data, family = stats::gaussian())
 
     trend_p_crude<-summary(model_crude_trend)$coefficients[2, 4]
     trend_p_adj<-summary(model_adj_trend )$coefficients[2, 4]
-    #输出p-trend
+    #Output p-trend
     p_for_trend<-c('', '', '',
                      ifelse(trend_p_crude < 0.001, '<0.001', sprintf("%.3f", trend_p_crude)),
                      '',
                      ifelse(trend_p_adj   < 0.001, '<0.001', sprintf("%.3f", trend_p_adj)))
-    #计算OR值
+    #Compute OR
     level<-length(levels(xx))
     beita_estimate_crude<-summary(model_crude)$coefficients[2:level, 1]
     beita_lowerCI_crude<-summary(model_crude)$coefficients[2:level, 1] + stats::qnorm(0.025)*summary(model_crude)$coefficients[2:level, 2]
@@ -36,7 +42,7 @@ general<-function(x, y,adj, data,outformat=2){
     beita_estimate_adj<-summary(model_adj)$coefficients[2:level, 1]
     beita_lowerCI_adj<-summary(model_adj)$coefficients[2:level, 1] + stats::qnorm(0.025)*summary(model_adj)$coefficients[2:level, 2]
     beita_upperCI_adj<-summary(model_adj)$coefficients[2:level, 1] + stats::qnorm(0.975)*summary(model_adj)$coefficients[2:level, 2]
-    #输出OR值和p值
+    #Output OR, p value
     beita_crude<-c('ref',
                      paste0(sprintf("%.2f", beita_estimate_crude), '(',
                              sprintf("%.2f", beita_lowerCI_crude),  ',',
@@ -70,7 +76,7 @@ general<-function(x, y,adj, data,outformat=2){
     var_information<-rbind(var_information, data.frame(matrix(p_for_trend,nrow=1)))
   }
   else{
-    #计算OR值
+    #Compute OR
     beita_estimate_crude<-summary(model_crude)$coefficients[2, 1]
     beita_lowerCI_crude<-summary(model_crude)$coefficients[2, 1] + stats::qnorm(0.025)*summary(model_crude)$coefficients[2, 2]
     beita_upperCI_crude<-summary(model_crude)$coefficients[2, 1] + stats::qnorm(0.975)*summary(model_crude)$coefficients[2, 2]
@@ -78,7 +84,7 @@ general<-function(x, y,adj, data,outformat=2){
     beita_estimate_adj<-summary(model_adj)$coefficients[2, 1]
     beita_lowerCI_adj<-summary(model_adj)$coefficients[2, 1] + stats::qnorm(0.025)*summary(model_adj)$coefficients[2, 2]
     beita_upperCI_adj<-summary(model_adj)$coefficients[2, 1] + stats::qnorm(0.975)*summary(model_adj)$coefficients[2, 2]
-    #输出OR值和p值
+    #Output OR, p value
     beita_crude<-paste0(sprintf("%.2f", beita_estimate_crude), '(',
                            sprintf("%.2f", beita_lowerCI_crude),  ',',
                            sprintf("%.2f", beita_upperCI_crude),  ')')
@@ -105,35 +111,41 @@ general<-function(x, y,adj, data,outformat=2){
   return(var_information)
 }
 ###############################################################
-logistic<-function(x, y, adj, data,case=2,condition='quantile'){
+logistic<-function(x, y, adj=NULL, data,case=2,condition='quantile'){
   xx<-data[,x]
   yy<-data[,y]
   case1<-levels(yy)[case]
-  #确认调整变量不同于x,y
-  adj1<-setdiff(adj, c(x, y))
-  #model和调整model的表达式
+  #Formula of model
   formula_crude<-stats::as.formula(paste0(y, ' ~ ', x))
-  formula_adj<-stats::as.formula(paste0(y, ' ~ ', x , ' + ', paste(adj1, collapse = ' + ')))
-  #logistic回归
+  if(length(adj)==0){
+    formula_adj<-stats::as.formula(paste0(y, ' ~ ', x))
+  }else{
+    formula_adj<-stats::as.formula(paste0(y, ' ~ ', x , ' + ', paste(adj, collapse = ' + ')))
+    }
+  #Logistic regression
   model_crude<-stats::glm(formula_crude, data = data, family = stats::binomial(link = "logit"))
   model_adj<-stats::glm(formula_adj,   data = data, family = stats::binomial(link = "logit"))
-  #计算OR值、p值并输出
+  #Compute OR, p value
   if(is.factor(xx)){
-    #计算p-trend
+    #Compute p-trend
     formula_crude_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ')'))
     model_crude_trend<-stats::glm(formula_crude_trend, data = data, family = stats::binomial(link = "logit"))
 
-    formula_adj_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ') +', paste(adj1, collapse = ' + ')))
+    if(length(adj)==0){
+      formula_adj_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ')'))
+    }else{
+      formula_adj_trend<-stats::as.formula(paste0(y, ' ~ as.numeric(', x, ') +', paste(adj, collapse = ' + ')))
+      }
     model_adj_trend<-stats::glm(formula_adj_trend, data = data, family = stats::binomial(link = "logit"))
 
     trend_p_crude<-summary(model_crude_trend)$coefficients[2, 4]
     trend_p_adj<-summary(model_adj_trend  )$coefficients[2, 4]
-    #输出p-trend
+    #Compute p-trend
     p_for_trend<-c(rep('',3),
                    ifelse(trend_p_crude < 0.001, '<0.001', sprintf("%.3f", trend_p_crude)),
                    rep('',1),
                    ifelse(trend_p_adj   < 0.001, '<0.001', sprintf("%.3f", trend_p_adj)))
-    #计算OR值
+    #Compute OR
     level<-length(levels(xx))
     OR_estimate_crude<-exp(summary(model_crude)$coefficients[2:level, 1])
     OR_lowerCI_crude<-exp(summary(model_crude)$coefficients[2:level, 1] + stats::qnorm(0.025)*summary(model_crude)$coefficients[2:level, 2])
@@ -142,7 +154,7 @@ logistic<-function(x, y, adj, data,case=2,condition='quantile'){
     OR_estimate_adj<-exp(summary(model_adj)$coefficients[2:level, 1])
     OR_lowerCI_adj<-exp(summary(model_adj)$coefficients[2:level, 1] + stats::qnorm(0.025)*summary(model_adj)$coefficients[2:level, 2])
     OR_upperCI_adj<-exp(summary(model_adj)$coefficients[2:level, 1] + stats::qnorm(0.975)*summary(model_adj)$coefficients[2:level, 2])
-    #输出OR值和p值
+    #Output OR, p value
     OR_crude<-c('ref',
                   paste0(sprintf("%.2f", OR_estimate_crude), '(',
                           sprintf("%.2f", OR_lowerCI_crude),  ',',
@@ -161,7 +173,7 @@ logistic<-function(x, y, adj, data,case=2,condition='quantile'){
                        sprintf('%.3f', summary(model_adj)$coefficients[2:level, 4])))
 
     intertable<-table(data.frame(xx, yy))
-    #广播
+    #Broadcasting
     N<-intertable[ ,1] + intertable[ ,2]
     Case<-intertable[ ,case]
     Percent<-paste0(Case, '(', sprintf('%.1f', 100*Case/N), ')')
@@ -173,7 +185,7 @@ logistic<-function(x, y, adj, data,case=2,condition='quantile'){
     }
 
   } else{
-    #计算OR值
+    #Compute OR
     OR_estimate_crude<-exp(summary(model_crude)$coefficients[2, 1])
     OR_lowerCI_crude<-exp(summary(model_crude)$coefficients[2, 1] + stats::qnorm(0.025)*summary(model_crude)$coefficients[2, 2])
     OR_upperCI_crude<-exp(summary(model_crude)$coefficients[2, 1] + stats::qnorm(0.975)*summary(model_crude)$coefficients[2, 2])
@@ -181,7 +193,7 @@ logistic<-function(x, y, adj, data,case=2,condition='quantile'){
     OR_estimate_adj<-exp(summary(model_adj)$coefficients[2, 1])
     OR_lowerCI_adj<-exp(summary(model_adj)$coefficients[2, 1] + stats::qnorm(0.025)*summary(model_adj)$coefficients[2, 2])
     OR_upperCI_adj<-exp(summary(model_adj)$coefficients[2, 1] + stats::qnorm(0.975)*summary(model_adj)$coefficients[2, 2])
-    #输出OR值和p值
+    #Compute OR, p value
     OR_crude<-paste0(sprintf("%.2f", OR_estimate_crude), '(',
                         sprintf("%.2f", OR_lowerCI_crude),  ',',
                         sprintf("%.2f", OR_upperCI_crude),  ')')
@@ -206,36 +218,42 @@ logistic<-function(x, y, adj, data,case=2,condition='quantile'){
 }
 
 ###############################################################
-con_logistic<-function(x, y,strata,adj, data,case=2){
+con_logistic<-function(x, y,strata,adj=NULL, data,case=2){
   xx<-data[,x]
   yy<-data[,y]
   case1<-levels(yy)[case]
   s<-data[,strata]#diff
-  #确认调整变量不同于x,y
-  adj1<-setdiff(adj, c(x, y,strata))#diff
-  #model和调整model的表达式
+  #Formula of model
   formula_crude<-stats::as.formula(paste0('as.numeric(',y, ') ',' ~ ', x,' + ','strata(',strata,')'))
-  formula_adj<-stats::as.formula(paste0('as.numeric(',y,') ', ' ~ ', x , ' + strata(',strata,') +', paste(adj1, collapse = ' + ')))
-  #con_logistic回归
+  if(length(adj)==0){
+    formula_adj<-stats::as.formula(paste0('as.numeric(',y, ') ',' ~ ', x,' + ','strata(',strata,')'))
+  }else{
+    formula_adj<-stats::as.formula(paste0('as.numeric(',y,') ', ' ~ ', x , ' + strata(',strata,') +', paste(adj, collapse = ' + ')))
+    }
+  #Con_logistic regression
   model_crude<-survival::clogit(formula_crude, data = data)
   model_adj<-survival::clogit(formula_adj,   data = data)
-  #计算OR值、p值并输出
+  #Compute OR、p value
   if(is.factor(xx)){
-    #计算p-trend
+    #Compute p-trend
     formula_crude_trend<-stats::as.formula(paste0('as.numeric(', y, ') ', ' ~ as.numeric(', x, ') + strata(',strata,')'))
     model_crude_trend<-survival::clogit(formula_crude_trend, data = data)#diff
 
-    formula_adj_trend<-stats::as.formula(paste0('as.numeric(', y,') ', ' ~ as.numeric(', x, ') + strata(',strata,') + ', paste(adj1, collapse = ' + ')))
+    if(length(adj)==0){
+      formula_adj_trend<-stats::as.formula(paste0('as.numeric(', y, ') ', ' ~ as.numeric(', x, ') + strata(',strata,')'))
+    }else{
+      formula_adj_trend<-stats::as.formula(paste0('as.numeric(', y,') ', ' ~ as.numeric(', x, ') + strata(',strata,') + ', paste(adj, collapse = ' + ')))
+      }
     model_adj_trend<-survival::clogit(formula_adj_trend, data = data) #diff
 
     trend_p_crude<-summary(model_crude_trend)$coefficients[1,5]#diff
     trend_p_adj<-summary(model_adj_trend  )$coefficients[1,5]
-    #输出p-trend
+    #Compute p-trend
     p_for_trend<-c(rep('',3),
                    ifelse(trend_p_crude < 0.001, '<0.001', sprintf("%.3f", trend_p_crude)),
                    rep('',1),
                    ifelse(trend_p_adj   < 0.001, '<0.001', sprintf("%.3f", trend_p_adj)))
-    #计算OR值
+    #Compute OR
     level<-length(levels(xx)) #diff
     OR_estimate_crude<-summary(model_crude)$conf.int[1:level-1, 1]
     OR_lowerCI_crude<-summary(model_crude)$conf.int[1:level-1, 3]
@@ -244,7 +262,7 @@ con_logistic<-function(x, y,strata,adj, data,case=2){
     OR_estimate_adj<-summary(model_adj)$conf.int[1:level-1, 1]
     OR_lowerCI_adj<-summary(model_adj)$conf.int[1:level-1, 3]
     OR_upperCI_adj<-summary(model_adj)$conf.int[1:level-1, 4]
-    #输出OR值和p值
+    #Compute OR, p value
     OR_crude<-c('ref',
                   paste0(sprintf("%.2f", OR_estimate_crude), '(',
                           sprintf("%.2f", OR_lowerCI_crude),  ',',
@@ -263,7 +281,7 @@ con_logistic<-function(x, y,strata,adj, data,case=2){
                        sprintf('%.3f', summary(model_adj)$coefficients[1:level-1, 5])))
 
     intertable<-table(data.frame(xx, yy))
-    #广播
+    #Broadcasting
     N<-intertable[ ,1] + intertable[ ,2]
     Case<-intertable[ ,case]
     Control<-N-Case
@@ -272,7 +290,7 @@ con_logistic<-function(x, y,strata,adj, data,case=2){
     var_information<-rbind(var_information, data.frame(matrix(p_for_trend,nrow=1)))
   }
   else{
-    #计算OR值
+    #Compute OR
     OR_estimate_crude<-summary(model_crude)$conf.int[1,1]
     OR_lowerCI_crude<-summary(model_crude)$conf.int[1,3]
     OR_upperCI_crude<-summary(model_crude)$conf.int[1,4]
@@ -280,7 +298,7 @@ con_logistic<-function(x, y,strata,adj, data,case=2){
     OR_estimate_adj<-summary(model_adj)$conf.int[1,1]
     OR_lowerCI_adj<-summary(model_adj)$conf.int[1,3]
     OR_upperCI_adj<-summary(model_adj)$conf.int[1,4]
-    #输出OR值和p值
+    #Output OR, p value
     OR_crude<-paste0(sprintf("%.2f", OR_estimate_crude), '(',
                         sprintf("%.2f", OR_lowerCI_crude),  ',',
                         sprintf("%.2f", OR_upperCI_crude),  ')')
@@ -306,36 +324,42 @@ con_logistic<-function(x, y,strata,adj, data,case=2){
 }
 
 ###############################################################
-cox<-function(x, y_time, y_factor,adj, data,case=2){
+cox<-function(x, y_time, y_factor,adj=NULL, data,case=2){
   xx<-data[,x]
   yy_time<-data[,y_time]
   yy_factor<-data[,y_factor]
   case1<-levels(yy_factor)[case]
-  #确认调整变量不同于x,y
-  adj1<-setdiff(adj, c(x, y_time,y_factor))
-  #model和调整model的表达式
+  #Formula of model
   formula_crude<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', x))
-  formula_adj<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', x, ' + ', paste(adj1, collapse = ' + ')))
-  #cox回归
+  if(length(adj)==0){
+    formula_adj<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', x))
+  }else{
+    formula_adj<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', x, ' + ', paste(adj, collapse = ' + ')))
+    }
+  #Cox regression
   model_crude<-survival::coxph(formula_crude, data = data)
   model_adj<-survival::coxph(formula_adj, data = data)
-  #计算OR值 p值并输出
+  #Compute OR, p value
   if(is.factor(xx)){
-    #计算p-trend
+    #Compute p-trend
     formula_crude_trend<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', 'as.numeric(', x, ')'))
     model_crude_trend<-survival::coxph(formula_crude_trend, data = data)#diff
 
-    formula_adj_trend<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', 'as.numeric(', x, ') + ', paste(adj1, collapse = ' + ')))
+    if(length(adj)==0){
+      formula_adj_trend<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', 'as.numeric(', x, ')'))
+    }else{
+      formula_adj_trend<-stats::as.formula(paste0('survival::Surv(',y_time,' , as.numeric(',y_factor,')) ~ ', 'as.numeric(', x, ') + ', paste(adj, collapse = ' + ')))
+      }
     model_adj_trend<-survival::coxph(formula_adj_trend, data = data) #diff
 
     trend_p_crude<-summary(model_crude_trend)$coefficients[1,5]#diff
     trend_p_adj<-summary(model_adj_trend  )$coefficients[1,5]
-    #输出p-trend
+    #Compute p-trend
     p_for_trend<-c(rep('',3),
                    ifelse(trend_p_crude < 0.001, '<0.001', sprintf("%.3f", trend_p_crude)),
                    rep('',1),
                    ifelse(trend_p_adj   < 0.001, '<0.001', sprintf("%.3f", trend_p_adj)))
-    #计算OR值
+    #compute OR
     level<-length(levels(xx)) #diff
     OR_estimate_crude<-summary(model_crude)$conf.int[1:level-1, 1]
     OR_lowerCI_crude<-summary(model_crude)$conf.int[1:level-1, 3]
@@ -344,7 +368,7 @@ cox<-function(x, y_time, y_factor,adj, data,case=2){
     OR_estimate_adj<-summary(model_adj)$conf.int[1:level-1, 1]
     OR_lowerCI_adj<-summary(model_adj)$conf.int[1:level-1, 3]
     OR_upperCI_adj<-summary(model_adj)$conf.int[1:level-1, 4]
-    #输出OR值和p值
+    #Output OR, p value
     OR_crude<-c('ref',
                   paste0(sprintf("%.2f", OR_estimate_crude), '(',
                           sprintf("%.2f", OR_lowerCI_crude),  ',',
@@ -363,7 +387,7 @@ cox<-function(x, y_time, y_factor,adj, data,case=2){
                        sprintf('%.3f', summary(model_adj)$coefficients[1:level-1, 5])))
 
     intertable<-table(data.frame(xx, yy_factor))
-    #广播
+    #Broadcasting
     N<-intertable[ ,1] + intertable[ ,2]
     Case<-intertable[ ,case]
     Percent<-paste0(Case, '(', sprintf('%.1f', 100*Case/N), ')')
@@ -371,7 +395,7 @@ cox<-function(x, y_time, y_factor,adj, data,case=2){
     var_information<-rbind(var_information, data.frame(matrix(p_for_trend,nrow=1)))
   }
   else{
-    #计算OR值
+    #Compute OR
     OR_estimate_crude<-summary(model_crude)$conf.int[1,1]
     OR_lowerCI_crude<-summary(model_crude)$conf.int[1,3]
     OR_upperCI_crude<-summary(model_crude)$conf.int[1,4]
@@ -379,7 +403,7 @@ cox<-function(x, y_time, y_factor,adj, data,case=2){
     OR_estimate_adj<-summary(model_adj)$conf.int[1,1]
     OR_lowerCI_adj<-summary(model_adj)$conf.int[1,3]
     OR_upperCI_adj<-summary(model_adj)$conf.int[1,4]
-    #输出OR值和p值
+    #Compute OR, p value
     OR_crude<-paste0(sprintf("%.2f", OR_estimate_crude), '(',
                         sprintf("%.2f", OR_lowerCI_crude),  ',',
                         sprintf("%.2f", OR_upperCI_crude),  ')')
